@@ -22,7 +22,7 @@
 
 #include "gtksourcecompletionwordsbuffer.h"
 #include "gtksourcecompletionwordsutils.h"
-#include "gtksourceview/gtktextregion.h"
+#include "gtksourceview/gtksourceregion.h"
 
 /* Timeout in seconds */
 #define INITIATE_SCAN_TIMEOUT 5
@@ -41,7 +41,7 @@ struct _GtkSourceCompletionWordsBufferPrivate
 	GtkSourceCompletionWordsLibrary *library;
 	GtkTextBuffer *buffer;
 
-	GtkTextRegion *scan_region;
+	GtkSourceRegion *scan_region;
 	gulong batch_scan_id;
 	gulong initiate_scan_id;
 
@@ -72,8 +72,8 @@ proposal_cache_free (ProposalCache *cache)
 
 static void
 remove_proposal_cache (const gchar                    *key,
-                       ProposalCache                  *cache,
-                       GtkSourceCompletionWordsBuffer *buffer)
+		       ProposalCache                  *cache,
+		       GtkSourceCompletionWordsBuffer *buffer)
 {
 	guint i;
 
@@ -108,12 +108,6 @@ gtk_source_completion_words_buffer_dispose (GObject *object)
 		buffer->priv->words = NULL;
 	}
 
-	if (buffer->priv->scan_region != NULL)
-	{
-		gtk_text_region_destroy (buffer->priv->scan_region);
-		buffer->priv->scan_region = NULL;
-	}
-
 	if (buffer->priv->batch_scan_id != 0)
 	{
 		g_source_remove (buffer->priv->batch_scan_id);
@@ -126,6 +120,7 @@ gtk_source_completion_words_buffer_dispose (GObject *object)
 		buffer->priv->initiate_scan_id = 0;
 	}
 
+	g_clear_object (&buffer->priv->scan_region);
 	g_clear_object (&buffer->priv->buffer);
 	g_clear_object (&buffer->priv->library);
 
@@ -200,7 +195,7 @@ scan_line (GtkSourceCompletionWordsBuffer *buffer,
 
 static void
 remove_word (GtkSourceCompletionWordsBuffer *buffer,
-             const gchar                    *word)
+	     const gchar                    *word)
 {
 	ProposalCache *cache = g_hash_table_lookup (buffer->priv->words, word);
 
@@ -224,7 +219,7 @@ remove_word (GtkSourceCompletionWordsBuffer *buffer,
 
 static void
 add_words (GtkSourceCompletionWordsBuffer *buffer,
-           GSList                         *words)
+	   GSList                         *words)
 {
 	GSList *item;
 
@@ -302,63 +297,28 @@ scan_region (GtkSourceCompletionWordsBuffer *buffer,
 	return nb_lines_scanned;
 }
 
-/* A TextRegion can contain empty subregions. So checking the number of
- * subregions is not sufficient.
- * When calling gtk_text_region_add() with equal iters, the subregion is not
- * added. But when a subregion becomes empty, due to text deletion, the
- * subregion is not removed from the TextRegion.
- */
-static gboolean
-is_text_region_empty (GtkTextRegion *region)
-{
-	GtkTextRegionIterator region_iter;
-
-	gtk_text_region_get_iterator (region, &region_iter, 0);
-
-	while (!gtk_text_region_iterator_is_end (&region_iter))
-	{
-		GtkTextIter region_start;
-		GtkTextIter region_end;
-
-		gtk_text_region_iterator_get_subregion (&region_iter,
-							&region_start,
-							&region_end);
-
-		if (!gtk_text_iter_equal (&region_start, &region_end))
-		{
-			return FALSE;
-		}
-
-		gtk_text_region_iterator_next (&region_iter);
-	}
-
-	return TRUE;
-}
-
 static gboolean
 idle_scan_regions (GtkSourceCompletionWordsBuffer *buffer)
 {
 	guint nb_remaining_lines = buffer->priv->scan_batch_size;
-	GtkTextRegionIterator region_iter;
+	GtkSourceRegionIter region_iter;
 	GtkTextIter start;
 	GtkTextIter stop;
 
 	gtk_text_buffer_get_start_iter (buffer->priv->buffer, &start);
 	stop = start;
 
-	gtk_text_region_get_iterator (buffer->priv->scan_region,
-				      &region_iter,
-				      0);
+	gtk_source_region_get_start_region_iter (buffer->priv->scan_region, &region_iter);
 
 	while (nb_remaining_lines > 0 &&
-	       !gtk_text_region_iterator_is_end (&region_iter))
+	       !gtk_source_region_iter_is_end (&region_iter))
 	{
 		GtkTextIter region_start;
 		GtkTextIter region_end;
 
-		gtk_text_region_iterator_get_subregion (&region_iter,
-							&region_start,
-							&region_end);
+		gtk_source_region_iter_get_subregion (&region_iter,
+						      &region_start,
+						      &region_end);
 
 		nb_remaining_lines -= scan_region (buffer,
 						   &region_start,
@@ -366,14 +326,14 @@ idle_scan_regions (GtkSourceCompletionWordsBuffer *buffer)
 						   nb_remaining_lines,
 						   &stop);
 
-		gtk_text_region_iterator_next (&region_iter);
+		gtk_source_region_iter_next (&region_iter);
 	}
 
-	gtk_text_region_subtract (buffer->priv->scan_region,
-				  &start,
-				  &stop);
+	gtk_source_region_subtract (buffer->priv->scan_region,
+				    &start,
+				    &stop);
 
-	if (is_text_region_empty (buffer->priv->scan_region))
+	if (gtk_source_region_is_empty (buffer->priv->scan_region))
 	{
 		buffer->priv->batch_scan_id = 0;
 		return G_SOURCE_REMOVE;
@@ -438,57 +398,55 @@ remove_words_in_subregion (GtkSourceCompletionWordsBuffer *buffer,
 
 static void
 remove_words_in_region (GtkSourceCompletionWordsBuffer *buffer,
-			GtkTextRegion                  *region)
+			GtkSourceRegion                *region)
 {
-	GtkTextRegionIterator region_iter;
+	GtkSourceRegionIter region_iter;
 
-	gtk_text_region_get_iterator (region, &region_iter, 0);
+	gtk_source_region_get_start_region_iter (region, &region_iter);
 
-	while (!gtk_text_region_iterator_is_end (&region_iter))
+	while (!gtk_source_region_iter_is_end (&region_iter))
 	{
 		GtkTextIter subregion_start;
 		GtkTextIter subregion_end;
 
-		gtk_text_region_iterator_get_subregion (&region_iter,
-							&subregion_start,
-							&subregion_end);
+		gtk_source_region_iter_get_subregion (&region_iter,
+						      &subregion_start,
+						      &subregion_end);
 
 		remove_words_in_subregion (buffer,
 					   &subregion_start,
 					   &subregion_end);
 
-		gtk_text_region_iterator_next (&region_iter);
+		gtk_source_region_iter_next (&region_iter);
 	}
 }
 
-static GtkTextRegion *
+static GtkSourceRegion *
 compute_remove_region (GtkSourceCompletionWordsBuffer *buffer,
 		       const GtkTextIter              *start,
 		       const GtkTextIter              *end)
 {
-	GtkTextRegion *remove_region = gtk_text_region_new (buffer->priv->buffer);
-	GtkTextRegionIterator region_iter;
+	GtkSourceRegion *remove_region = gtk_source_region_new (buffer->priv->buffer);
+	GtkSourceRegionIter region_iter;
 
-	gtk_text_region_add (remove_region, start, end);
+	gtk_source_region_add (remove_region, start, end);
 
-	gtk_text_region_get_iterator (buffer->priv->scan_region,
-				      &region_iter,
-				      0);
+	gtk_source_region_get_start_region_iter (buffer->priv->scan_region, &region_iter);
 
-	while (!gtk_text_region_iterator_is_end (&region_iter))
+	while (!gtk_source_region_iter_is_end (&region_iter))
 	{
 		GtkTextIter scan_start;
 		GtkTextIter scan_end;
 
-		gtk_text_region_iterator_get_subregion (&region_iter,
-							&scan_start,
-							&scan_end);
+		gtk_source_region_iter_get_subregion (&region_iter,
+						      &scan_start,
+						      &scan_end);
 
-		gtk_text_region_subtract (remove_region,
-					  &scan_start,
-					  &scan_end);
+		gtk_source_region_subtract (remove_region,
+					    &scan_start,
+					    &scan_end);
 
-		gtk_text_region_iterator_next (&region_iter);
+		gtk_source_region_iter_next (&region_iter);
 	}
 
 	return remove_region;
@@ -500,34 +458,34 @@ compute_remove_region (GtkSourceCompletionWordsBuffer *buffer,
  */
 static void
 invalidate_region (GtkSourceCompletionWordsBuffer *buffer,
-                   const GtkTextIter              *start,
-                   const GtkTextIter              *end)
+		   const GtkTextIter              *start,
+		   const GtkTextIter              *end)
 {
 	GtkTextIter start_iter = *start;
 	GtkTextIter end_iter = *end;
-	GtkTextRegion *remove_region;
+	GtkSourceRegion *remove_region;
 
 	_gtk_source_completion_words_utils_adjust_region (&start_iter, &end_iter);
 
 	remove_region = compute_remove_region (buffer, &start_iter, &end_iter);
 
 	remove_words_in_region (buffer, remove_region);
-	gtk_text_region_destroy (remove_region);
+	g_clear_object (&remove_region);
 }
 
 static void
 add_to_scan_region (GtkSourceCompletionWordsBuffer *buffer,
-                    const GtkTextIter              *start,
-                    const GtkTextIter              *end)
+		    const GtkTextIter              *start,
+		    const GtkTextIter              *end)
 {
 	GtkTextIter start_iter = *start;
 	GtkTextIter end_iter = *end;
 
 	_gtk_source_completion_words_utils_adjust_region (&start_iter, &end_iter);
 
-	gtk_text_region_add (buffer->priv->scan_region,
-			     &start_iter,
-			     &end_iter);
+	gtk_source_region_add (buffer->priv->scan_region,
+			       &start_iter,
+			       &end_iter);
 
 	install_initiate_scan (buffer);
 }
@@ -555,9 +513,9 @@ on_insert_text_after_cb (GtkTextBuffer                  *textbuffer,
 	gtk_text_iter_backward_chars (&start_iter, nb_chars);
 
 	/* If add_to_scan_region() is called before the text insertion, the
-	 * created GtkTextRegion can be empty and is thus not added to the
+	 * created GtkSourceRegion can be empty and is thus not added to the
 	 * scan region. After the text insertion, we are sure that the
-	 * GtkTextRegion is not empty and that the words will be scanned.
+	 * GtkSourceRegion is not empty and that the words will be scanned.
 	 */
 	add_to_scan_region (buffer, &start_iter, location);
 }
@@ -579,8 +537,8 @@ on_delete_range_before_cb (GtkTextBuffer                  *text_buffer,
 	{
 		remove_all_words (buffer);
 
-		gtk_text_region_destroy (buffer->priv->scan_region);
-		buffer->priv->scan_region = gtk_text_region_new (text_buffer);
+		g_clear_object (&buffer->priv->scan_region);
+		buffer->priv->scan_region = gtk_source_region_new (text_buffer);
 	}
 	else
 	{
@@ -597,9 +555,9 @@ on_delete_range_after_cb (GtkTextBuffer                  *text_buffer,
 	/* start = end, but add_to_scan_region() adjusts the iters to word
 	 * boundaries if needed. If the adjusted [start,end] region is empty, it
 	 * won't be added to the scan region. If we call add_to_scan_region()
-	 * when the text is not already deleted, the GtkTextRegion is not empty
-	 * and will be added to the scan region, and when the GtkTextRegion
-	 * becomes empty after the text deletion, the GtkTextRegion is not
+	 * when the text is not already deleted, the GtkSourceRegion is not empty
+	 * and will be added to the scan region, and when the GtkSourceRegion
+	 * becomes empty after the text deletion, the GtkSourceRegion is not
 	 * removed from the scan region. Hence two callbacks: before and after
 	 * the text deletion.
 	 */
@@ -616,9 +574,9 @@ scan_all_buffer (GtkSourceCompletionWordsBuffer *buffer)
 	                            &start,
 	                            &end);
 
-	gtk_text_region_add (buffer->priv->scan_region,
-			     &start,
-			     &end);
+	gtk_source_region_add (buffer->priv->scan_region,
+			       &start,
+			       &end);
 
 	install_initiate_scan (buffer);
 }
@@ -672,7 +630,7 @@ on_library_lock (GtkSourceCompletionWordsBuffer *buffer)
 static void
 on_library_unlock (GtkSourceCompletionWordsBuffer *buffer)
 {
-	if (!is_text_region_empty (buffer->priv->scan_region))
+	if (!gtk_source_region_is_empty (buffer->priv->scan_region))
 	{
 		install_initiate_scan (buffer);
 	}
@@ -680,7 +638,7 @@ on_library_unlock (GtkSourceCompletionWordsBuffer *buffer)
 
 GtkSourceCompletionWordsBuffer *
 gtk_source_completion_words_buffer_new (GtkSourceCompletionWordsLibrary *library,
-                                        GtkTextBuffer                   *buffer)
+					GtkTextBuffer                   *buffer)
 {
 	GtkSourceCompletionWordsBuffer *ret;
 
@@ -692,7 +650,7 @@ gtk_source_completion_words_buffer_new (GtkSourceCompletionWordsLibrary *library
 	ret->priv->library = g_object_ref (library);
 	ret->priv->buffer = g_object_ref (buffer);
 
-	ret->priv->scan_region = gtk_text_region_new (buffer);
+	ret->priv->scan_region = gtk_source_region_new (buffer);
 
 	g_signal_connect_object (ret->priv->library,
 				 "lock",
@@ -721,7 +679,7 @@ gtk_source_completion_words_buffer_get_buffer (GtkSourceCompletionWordsBuffer *b
 
 void
 gtk_source_completion_words_buffer_set_scan_batch_size (GtkSourceCompletionWordsBuffer *buffer,
-                                                        guint                           size)
+							guint                           size)
 {
 	g_return_if_fail (GTK_SOURCE_IS_COMPLETION_WORDS_BUFFER (buffer));
 	g_return_if_fail (size != 0);
@@ -731,7 +689,7 @@ gtk_source_completion_words_buffer_set_scan_batch_size (GtkSourceCompletionWords
 
 void
 gtk_source_completion_words_buffer_set_minimum_word_size (GtkSourceCompletionWordsBuffer *buffer,
-                                                          guint                           size)
+							  guint                           size)
 {
 	g_return_if_fail (GTK_SOURCE_IS_COMPLETION_WORDS_BUFFER (buffer));
 	g_return_if_fail (size != 0);
