@@ -17,8 +17,8 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef __GTK_SOURCE_H__
-#define __GTK_SOURCE_H__
+#ifndef GTK_SOURCE_H
+#define GTK_SOURCE_H
 
 #include <gtksourceview/gtksourcetypes.h>
 #include <gtksourceview/gtksourcebuffer.h>
@@ -56,7 +56,7 @@
 #include <gtksourceview/gtksourceutils.h>
 #include <gtksourceview/gtksourceversion.h>
 #include <gtksourceview/gtksourceview.h>
-#include <gtksourceview/gtksourceview-typebuiltins.h>
+#include <gtksourceview/gtksourceview-enumtypes.h>
 #include <gtksourceview/gtksourceautocleanups.h>
 
-#endif /* __GTK_SOURCE_H__ */
+#endif /* GTK_SOURCE_H */
