@@ -19,8 +19,8 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef __GTK_SOURCE_BUFFER_PRIVATE_H__
-#define __GTK_SOURCE_BUFFER_PRIVATE_H__
+#ifndef GTK_SOURCE_BUFFER_PRIVATE_H
+#define GTK_SOURCE_BUFFER_PRIVATE_H
 
 #include <gtk/gtk.h>
 #include "gtksourcetypes.h"
@@ -77,4 +77,4 @@ gboolean		 _gtk_source_buffer_is_undo_redo_enabled	(GtkSourceBuffer        *buff
 
 G_END_DECLS
 
-#endif /* __GTK_SOURCE_BUFFER_PRIVATE_H__ */
+#endif /* GTK_SOURCE_BUFFER_PRIVATE_H */
