@@ -38,15 +38,15 @@
 #include "gtksourcelanguage-private.h"
 #include "gtksourceundomanager.h"
 #include "gtksourceundomanagerdefault.h"
+#include "gtksourcestyle.h"
 #include "gtksourcestylescheme.h"
 #include "gtksourcestyleschememanager.h"
-#include "gtksourcestyle-private.h"
 #include "gtksourcemark.h"
 #include "gtksourcemarkssequence.h"
 #include "gtksourcesearchcontext.h"
 #include "gtksourcetag.h"
 #include "gtksourceview-i18n.h"
-#include "gtksourceview-typebuiltins.h"
+#include "gtksourceview-enumtypes.h"
 
 /**
  * SECTION:buffer
@@ -96,7 +96,7 @@
  * undo's effect). Warning: the selection restoring behavior might change in the
  * future.
  *
- * # Context Classes
+ * # Context Classes # {#context-classes}
  *
  * It is possible to retrieve some information from the syntax highlighting
  * engine. The default context classes that are applied to regions of a
@@ -168,7 +168,6 @@
 #define BRACKET_MATCHING_CHARS_LIMIT	10000
 #define CONTEXT_CLASSES_PREFIX		"gtksourceview:context-classes:"
 
-/* Signals */
 enum
 {
 	HIGHLIGHT_UPDATED,
@@ -176,10 +175,9 @@ enum
 	UNDO,
 	REDO,
 	BRACKET_MATCHED,
-	LAST_SIGNAL
+	N_SIGNALS
 };
 
-/* Properties */
 enum
 {
 	PROP_0,
@@ -191,22 +189,23 @@ enum
 	PROP_LANGUAGE,
 	PROP_STYLE_SCHEME,
 	PROP_UNDO_MANAGER,
-	PROP_IMPLICIT_TRAILING_NEWLINE
+	PROP_IMPLICIT_TRAILING_NEWLINE,
+	N_PROPERTIES
 };
 
 struct _GtkSourceBufferPrivate
 {
 	GtkTextTag *bracket_match_tag;
 	GtkSourceBracketMatchType bracket_match_state;
+	guint bracket_highlighting_timeout_id;
 
 	/* Hash table: category -> MarksSequence */
 	GHashTable *source_marks;
 	GtkSourceMarksSequence *all_source_marks;
 
-	GtkSourceLanguage *language;
-
-	GtkSourceEngine *highlight_engine;
 	GtkSourceStyleScheme *style_scheme;
+	GtkSourceLanguage *language;
+	GtkSourceEngine *highlight_engine;
 
 	GtkSourceUndoManager *undo_manager;
 	gint max_undo_levels;
@@ -218,14 +217,13 @@ struct _GtkSourceBufferPrivate
 
 	GtkTextTag *invalid_char_tag;
 
-	guint bracket_update_handler;
-
 	guint highlight_syntax : 1;
 	guint highlight_brackets : 1;
 	guint implicit_trailing_newline : 1;
 };
 
-static guint buffer_signals[LAST_SIGNAL];
+static guint buffer_signals[N_SIGNALS];
+static GParamSpec *buffer_properties[N_PROPERTIES];
 
 G_DEFINE_TYPE_WITH_PRIVATE (GtkSourceBuffer, gtk_source_buffer, GTK_TYPE_TEXT_BUFFER)
 
@@ -314,26 +312,26 @@ gtk_source_buffer_class_init (GtkSourceBufferClass *klass)
 	 *
 	 * Whether to highlight syntax in the buffer.
 	 */
-	g_object_class_install_property (object_class,
-					 PROP_HIGHLIGHT_SYNTAX,
-					 g_param_spec_boolean ("highlight-syntax",
-							       "Highlight Syntax",
-							       "Whether to highlight syntax in the buffer",
-							       TRUE,
-							       G_PARAM_READWRITE));
+	buffer_properties[PROP_HIGHLIGHT_SYNTAX] =
+		g_param_spec_boolean ("highlight-syntax",
+				      "Highlight Syntax",
+				      "Whether to highlight syntax in the buffer",
+				      TRUE,
+				      G_PARAM_READWRITE |
+				      G_PARAM_STATIC_STRINGS);
 
 	/**
 	 * GtkSourceBuffer:highlight-matching-brackets:
 	 *
 	 * Whether to highlight matching brackets in the buffer.
 	 */
-	g_object_class_install_property (object_class,
-					 PROP_HIGHLIGHT_MATCHING_BRACKETS,
-					 g_param_spec_boolean ("highlight-matching-brackets",
-							       "Highlight Matching Brackets",
-							       "Whether to highlight matching brackets",
-							       TRUE,
-							       G_PARAM_READWRITE));
+	buffer_properties[PROP_HIGHLIGHT_MATCHING_BRACKETS] =
+		g_param_spec_boolean ("highlight-matching-brackets",
+				      "Highlight Matching Brackets",
+				      "Whether to highlight matching brackets",
+				      TRUE,
+				      G_PARAM_READWRITE |
+				      G_PARAM_STATIC_STRINGS);
 
 	/**
 	 * GtkSourceBuffer:max-undo-levels:
@@ -341,39 +339,39 @@ gtk_source_buffer_class_init (GtkSourceBufferClass *klass)
 	 * Number of undo levels for the buffer. -1 means no limit. This property
 	 * will only affect the default undo manager.
 	 */
-	g_object_class_install_property (object_class,
-					 PROP_MAX_UNDO_LEVELS,
-					 g_param_spec_int ("max-undo-levels",
-							   "Maximum Undo Levels",
-							   "Number of undo levels for the buffer",
-							   -1,
-							   G_MAXINT,
-							   -1,
-							   G_PARAM_READWRITE));
+	buffer_properties[PROP_MAX_UNDO_LEVELS] =
+		g_param_spec_int ("max-undo-levels",
+				  "Maximum Undo Levels",
+				  "Number of undo levels for the buffer",
+				  -1,
+				  G_MAXINT,
+				  -1,
+				  G_PARAM_READWRITE |
+				  G_PARAM_STATIC_STRINGS);
 
-	g_object_class_install_property (object_class,
-					 PROP_LANGUAGE,
-					 g_param_spec_object ("language",
-							      "Language",
-							      "Language object to get highlighting patterns from",
-							      GTK_SOURCE_TYPE_LANGUAGE,
-							      G_PARAM_READWRITE));
+	buffer_properties[PROP_LANGUAGE] =
+		g_param_spec_object ("language",
+				     "Language",
+				     "Language object to get highlighting patterns from",
+				     GTK_SOURCE_TYPE_LANGUAGE,
+				     G_PARAM_READWRITE |
+				     G_PARAM_STATIC_STRINGS);
 
-	g_object_class_install_property (object_class,
-					 PROP_CAN_UNDO,
-					 g_param_spec_boolean ("can-undo",
-							       "Can undo",
-							       "Whether Undo operation is possible",
-							       FALSE,
-							       G_PARAM_READABLE));
+	buffer_properties[PROP_CAN_UNDO] =
+		g_param_spec_boolean ("can-undo",
+				      "Can undo",
+				      "Whether Undo operation is possible",
+				      FALSE,
+				      G_PARAM_READABLE |
+				      G_PARAM_STATIC_STRINGS);
 
-	g_object_class_install_property (object_class,
-					 PROP_CAN_REDO,
-					 g_param_spec_boolean ("can-redo",
-							       "Can redo",
-							       "Whether Redo operation is possible",
-							       FALSE,
-							       G_PARAM_READABLE));
+	buffer_properties[PROP_CAN_REDO] =
+		g_param_spec_boolean ("can-redo",
+				      "Can redo",
+				      "Whether Redo operation is possible",
+				      FALSE,
+				      G_PARAM_READABLE |
+				      G_PARAM_STATIC_STRINGS);
 
 	/**
 	 * GtkSourceBuffer:style-scheme:
@@ -382,21 +380,22 @@ gtk_source_buffer_class_init (GtkSourceBufferClass *klass)
 	 * foreground, background, cursor color, current line color, and matching
 	 * brackets style.
 	 */
-	g_object_class_install_property (object_class,
-					 PROP_STYLE_SCHEME,
-					 g_param_spec_object ("style_scheme",
-							      "Style scheme",
-							      "Style scheme",
-							      GTK_SOURCE_TYPE_STYLE_SCHEME,
-							      G_PARAM_READWRITE));
+	buffer_properties[PROP_STYLE_SCHEME] =
+		g_param_spec_object ("style-scheme",
+				     "Style scheme",
+				     "Style scheme",
+				     GTK_SOURCE_TYPE_STYLE_SCHEME,
+				     G_PARAM_READWRITE |
+				     G_PARAM_STATIC_STRINGS);
 
-	g_object_class_install_property (object_class,
-	                                 PROP_UNDO_MANAGER,
-	                                 g_param_spec_object ("undo-manager",
-	                                                      "Undo manager",
-	                                                      "The buffer undo manager",
-	                                                      GTK_SOURCE_TYPE_UNDO_MANAGER,
-	                                                      G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+	buffer_properties[PROP_UNDO_MANAGER] =
+		g_param_spec_object ("undo-manager",
+				     "Undo manager",
+				     "The buffer undo manager",
+				     GTK_SOURCE_TYPE_UNDO_MANAGER,
+				     G_PARAM_READWRITE |
+				     G_PARAM_CONSTRUCT |
+				     G_PARAM_STATIC_STRINGS);
 
 	/**
 	 * GtkSourceBuffer:implicit-trailing-newline:
@@ -406,14 +405,16 @@ gtk_source_buffer_class_init (GtkSourceBufferClass *klass)
 	 *
 	 * Since: 3.14
 	 */
-	g_object_class_install_property (object_class,
-					 PROP_IMPLICIT_TRAILING_NEWLINE,
-					 g_param_spec_boolean ("implicit-trailing-newline",
-							       "Implicit trailing newline",
-							       "",
-							       TRUE,
-							       G_PARAM_READWRITE | G_PARAM_CONSTRUCT |
-							       G_PARAM_STATIC_STRINGS));
+	buffer_properties[PROP_IMPLICIT_TRAILING_NEWLINE] =
+		g_param_spec_boolean ("implicit-trailing-newline",
+				      "Implicit trailing newline",
+				      "",
+				      TRUE,
+				      G_PARAM_READWRITE |
+				      G_PARAM_CONSTRUCT |
+				      G_PARAM_STATIC_STRINGS);
+
+	g_object_class_install_properties (object_class, N_PROPERTIES, buffer_properties);
 
 	/**
 	 * GtkSourceBuffer::highlight-updated:
@@ -427,7 +428,7 @@ gtk_source_buffer_class_init (GtkSourceBufferClass *klass)
 	 * updated (e.g. the no-spell-check context class).
 	 */
 	buffer_signals[HIGHLIGHT_UPDATED] =
-	    g_signal_new_class_handler ("highlight_updated",
+	    g_signal_new_class_handler ("highlight-updated",
 	                                G_OBJECT_CLASS_TYPE (object_class),
 	                                G_SIGNAL_RUN_LAST,
 	                                G_CALLBACK (gtk_source_buffer_real_highlight_updated),
@@ -442,11 +443,11 @@ gtk_source_buffer_class_init (GtkSourceBufferClass *klass)
 	 * @buffer: the buffer that received the signal
 	 * @mark: the #GtkSourceMark
 	 *
-	 * The ::source_mark_updated signal is emitted each time
+	 * The ::source-mark-updated signal is emitted each time
 	 * a mark is added to, moved or removed from the @buffer.
 	 */
 	buffer_signals[SOURCE_MARK_UPDATED] =
-	    g_signal_new ("source_mark_updated",
+	    g_signal_new ("source-mark-updated",
 			   G_OBJECT_CLASS_TYPE (object_class),
 			   G_SIGNAL_RUN_LAST,
 			   0,
@@ -549,8 +550,8 @@ set_undo_manager (GtkSourceBuffer      *buffer,
 		                  buffer);
 
 		/* Notify possible changes in the can-undo/redo state */
-		g_object_notify (G_OBJECT (buffer), "can-undo");
-		g_object_notify (G_OBJECT (buffer), "can-redo");
+		g_object_notify_by_pspec (G_OBJECT (buffer), buffer_properties[PROP_CAN_UNDO]);
+		g_object_notify_by_pspec (G_OBJECT (buffer), buffer_properties[PROP_CAN_REDO]);
 	}
 }
 
@@ -595,10 +596,10 @@ gtk_source_buffer_dispose (GObject *object)
 	GtkSourceBuffer *buffer = GTK_SOURCE_BUFFER (object);
 	GList *l;
 
-	if (buffer->priv->bracket_update_handler != 0)
+	if (buffer->priv->bracket_highlighting_timeout_id != 0)
 	{
-		g_source_remove (buffer->priv->bracket_update_handler);
-		buffer->priv->bracket_update_handler = 0;
+		g_source_remove (buffer->priv->bracket_highlighting_timeout_id);
+		buffer->priv->bracket_highlighting_timeout_id = 0;
 	}
 
 	if (buffer->priv->undo_manager != NULL)
@@ -744,7 +745,7 @@ gtk_source_buffer_get_property (GObject    *object,
 
 /**
  * gtk_source_buffer_new:
- * @table: (allow-none): a #GtkTextTagTable, or %NULL to create a new one.
+ * @table: (nullable): a #GtkTextTagTable, or %NULL to create a new one.
  *
  * Creates a new source buffer.
  *
@@ -786,7 +787,7 @@ gtk_source_buffer_can_undo_handler (GtkSourceUndoManager *manager,
 {
 	g_return_if_fail (GTK_SOURCE_IS_BUFFER (buffer));
 
-	g_object_notify (G_OBJECT (buffer), "can-undo");
+	g_object_notify_by_pspec (G_OBJECT (buffer), buffer_properties[PROP_CAN_UNDO]);
 }
 
 static void
@@ -795,7 +796,7 @@ gtk_source_buffer_can_redo_handler (GtkSourceUndoManager *manager,
 {
 	g_return_if_fail (GTK_SOURCE_IS_BUFFER (buffer));
 
-	g_object_notify (G_OBJECT (buffer), "can-redo");
+	g_object_notify_by_pspec (G_OBJECT (buffer), buffer_properties[PROP_CAN_REDO]);
 }
 
 static void
@@ -813,7 +814,7 @@ update_bracket_match_style (GtkSourceBuffer *buffer)
 		style = _gtk_source_style_scheme_get_matching_brackets_style (buffer->priv->style_scheme);
 	}
 
-	_gtk_source_style_apply (style, buffer->priv->bracket_match_tag);
+	gtk_source_style_apply (style, buffer->priv->bracket_match_tag);
 }
 
 static GtkTextTag *
@@ -1072,27 +1073,25 @@ update_bracket_highlighting (GtkSourceBuffer *source_buffer)
 }
 
 static gboolean
-do_bracket_update (gpointer user_data)
+bracket_highlighting_timeout_cb (gpointer user_data)
 {
-	GtkSourceBuffer *buffer = user_data;
-
-	buffer->priv->bracket_update_handler = 0;
+	GtkSourceBuffer *buffer = GTK_SOURCE_BUFFER (user_data);
 
 	update_bracket_highlighting (buffer);
 
+	buffer->priv->bracket_highlighting_timeout_id = 0;
 	return G_SOURCE_REMOVE;
 }
 
 static void
-queue_bracket_update (GtkSourceBuffer *buffer)
+queue_bracket_highlighting_update (GtkSourceBuffer *buffer)
 {
-	if (buffer->priv->bracket_update_handler != 0)
+	if (buffer->priv->bracket_highlighting_timeout_id != 0)
 	{
-		g_source_remove (buffer->priv->bracket_update_handler);
+		g_source_remove (buffer->priv->bracket_highlighting_timeout_id);
 	}
 
-	/*
-	 * Queue an update to the bracket location instead of doing it
+	/* Queue an update to the bracket location instead of doing it
 	 * immediately. We are likely going to be servicing a draw deadline
 	 * immediately, so blocking to find the match and invalidating
 	 * visible regions causes animations to stutter. Instead, give
@@ -1109,21 +1108,22 @@ queue_bracket_update (GtkSourceBuffer *buffer)
 	 * If we had access to a GdkFrameClock, we might consider using
 	 * ::update() or ::after-paint() to synchronize this.
 	 */
-	buffer->priv->bracket_update_handler =
+	buffer->priv->bracket_highlighting_timeout_id =
 		gdk_threads_add_timeout_full (G_PRIORITY_LOW,
 					      UPDATE_BRACKET_DELAY,
-					      do_bracket_update,
+					      bracket_highlighting_timeout_cb,
 					      buffer,
 					      NULL);
 }
 
-/* Although this function is not really useful (update_bracket_highlighting()
- * could be called directly), the name cursor_moved() is more meaningful.
+/* Although this function is not really useful
+ * (queue_bracket_highlighting_update() could be called directly), the name
+ * cursor_moved() is more meaningful.
  */
 static void
 cursor_moved (GtkSourceBuffer *buffer)
 {
-	queue_bracket_update (buffer);
+	queue_bracket_highlighting_update (buffer);
 }
 
 static void
@@ -1131,7 +1131,7 @@ gtk_source_buffer_real_highlight_updated (GtkSourceBuffer *buffer,
 					  GtkTextIter     *start,
 					  GtkTextIter     *end)
 {
-	queue_bracket_update (buffer);
+	queue_bracket_highlighting_update (buffer);
 }
 
 static void
@@ -1568,7 +1568,7 @@ gtk_source_buffer_set_max_undo_levels (GtkSourceBuffer *buffer,
 		                                                     max_undo_levels);
 	}
 
-	g_object_notify (G_OBJECT (buffer), "max-undo-levels");
+	g_object_notify_by_pspec (G_OBJECT (buffer), buffer_properties[PROP_MAX_UNDO_LEVELS]);
 }
 
 gboolean
@@ -1669,7 +1669,7 @@ gtk_source_buffer_set_highlight_matching_brackets (GtkSourceBuffer *buffer,
 
 		update_bracket_highlighting (buffer);
 
-		g_object_notify (G_OBJECT (buffer), "highlight-matching-brackets");
+		g_object_notify_by_pspec (G_OBJECT (buffer), buffer_properties[PROP_HIGHLIGHT_MATCHING_BRACKETS]);
 	}
 }
 
@@ -1695,12 +1695,15 @@ gtk_source_buffer_get_highlight_syntax (GtkSourceBuffer *buffer)
  * @buffer: a #GtkSourceBuffer.
  * @highlight: %TRUE to enable syntax highlighting, %FALSE to disable it.
  *
- * Controls whether syntax is highlighted in the buffer. If @highlight
- * is %TRUE, the text will be highlighted according to the syntax
- * patterns specified in the language set with
- * gtk_source_buffer_set_language(). If @highlight is %FALSE, syntax highlighting
- * is disabled and all the GtkTextTag objects that have been added by the
- * syntax highlighting engine are removed from the buffer.
+ * Controls whether syntax is highlighted in the buffer.
+ *
+ * If @highlight is %TRUE, the text will be highlighted according to the syntax
+ * patterns specified in the #GtkSourceLanguage set with
+ * gtk_source_buffer_set_language().
+ *
+ * If @highlight is %FALSE, syntax highlighting is disabled and all the
+ * #GtkTextTag objects that have been added by the syntax highlighting engine
+ * are removed from the buffer.
  */
 void
 gtk_source_buffer_set_highlight_syntax (GtkSourceBuffer *buffer,
@@ -1713,20 +1716,20 @@ gtk_source_buffer_set_highlight_syntax (GtkSourceBuffer *buffer,
 	if (buffer->priv->highlight_syntax != highlight)
 	{
 		buffer->priv->highlight_syntax = highlight;
-		g_object_notify (G_OBJECT (buffer), "highlight-syntax");
+		g_object_notify_by_pspec (G_OBJECT (buffer), buffer_properties[PROP_HIGHLIGHT_SYNTAX]);
 	}
 }
 
 /**
  * gtk_source_buffer_set_language:
  * @buffer: a #GtkSourceBuffer.
- * @language: (allow-none): a #GtkSourceLanguage to set, or %NULL.
+ * @language: (nullable): a #GtkSourceLanguage to set, or %NULL.
  *
- * Associate a #GtkSourceLanguage with the buffer. If @language is
- * not-%NULL and syntax highlighting is enabled (see gtk_source_buffer_set_highlight_syntax()),
- * the syntax patterns defined in @language will be used to highlight the text
- * contained in the buffer. If @language is %NULL, the text contained in the
- * buffer is not highlighted.
+ * Associates a #GtkSourceLanguage with the buffer.
+ *
+ * Note that a #GtkSourceLanguage affects not only the syntax highlighting, but
+ * also the [context classes][context-classes]. If you want to disable just the
+ * syntax highlighting, see gtk_source_buffer_set_highlight_syntax().
  *
  * The buffer holds a reference to @language.
  */
@@ -1737,7 +1740,7 @@ gtk_source_buffer_set_language (GtkSourceBuffer   *buffer,
 	g_return_if_fail (GTK_SOURCE_IS_BUFFER (buffer));
 	g_return_if_fail (GTK_SOURCE_IS_LANGUAGE (language) || language == NULL);
 
-	if (buffer->priv->language == language)
+	if (!g_set_object (&buffer->priv->language, language))
 	{
 		return;
 	}
@@ -1750,26 +1753,17 @@ gtk_source_buffer_set_language (GtkSourceBuffer   *buffer,
 		buffer->priv->highlight_engine = NULL;
 	}
 
-	if (buffer->priv->language != NULL)
-	{
-		g_object_unref (buffer->priv->language);
-	}
-
-	buffer->priv->language = language;
-
 	if (language != NULL)
 	{
-		g_object_ref (language);
-
 		/* get a new engine */
 		buffer->priv->highlight_engine = _gtk_source_language_create_engine (language);
 
-		if (buffer->priv->highlight_engine)
+		if (buffer->priv->highlight_engine != NULL)
 		{
 			_gtk_source_engine_attach_buffer (buffer->priv->highlight_engine,
 							  GTK_TEXT_BUFFER (buffer));
 
-			if (buffer->priv->style_scheme)
+			if (buffer->priv->style_scheme != NULL)
 			{
 				_gtk_source_engine_set_style_scheme (buffer->priv->highlight_engine,
 								     buffer->priv->style_scheme);
@@ -1777,7 +1771,7 @@ gtk_source_buffer_set_language (GtkSourceBuffer   *buffer,
 		}
 	}
 
-	g_object_notify (G_OBJECT (buffer), "language");
+	g_object_notify_by_pspec (G_OBJECT (buffer), buffer_properties[PROP_LANGUAGE]);
 }
 
 /**
@@ -1867,11 +1861,22 @@ gtk_source_buffer_ensure_highlight (GtkSourceBuffer   *buffer,
 /**
  * gtk_source_buffer_set_style_scheme:
  * @buffer: a #GtkSourceBuffer.
- * @scheme: (allow-none): a #GtkSourceStyleScheme or %NULL.
+ * @scheme: (nullable): a #GtkSourceStyleScheme or %NULL.
  *
- * Sets style scheme used by the buffer. If @scheme is %NULL no
- * style scheme is used.
- **/
+ * Sets a #GtkSourceStyleScheme to be used by the buffer and the view.
+ *
+ * Note that a #GtkSourceStyleScheme affects not only the syntax highlighting,
+ * but also other #GtkSourceView features such as highlighting the current line,
+ * matching brackets, the line numbers, etc.
+ *
+ * Instead of setting a %NULL @scheme, it is better to disable syntax
+ * highlighting with gtk_source_buffer_set_highlight_syntax(), and setting the
+ * #GtkSourceStyleScheme with the "classic" or "tango" ID, because those two
+ * style schemes follow more closely the GTK+ theme (for example for the
+ * background color).
+ *
+ * The buffer holds a reference to @scheme.
+ */
 void
 gtk_source_buffer_set_style_scheme (GtkSourceBuffer      *buffer,
 				    GtkSourceStyleScheme *scheme)
@@ -1879,25 +1884,17 @@ gtk_source_buffer_set_style_scheme (GtkSourceBuffer      *buffer,
 	g_return_if_fail (GTK_SOURCE_IS_BUFFER (buffer));
 	g_return_if_fail (GTK_SOURCE_IS_STYLE_SCHEME (scheme) || scheme == NULL);
 
-	if (buffer->priv->style_scheme == scheme)
+	if (g_set_object (&buffer->priv->style_scheme, scheme))
 	{
-		return;
+		update_bracket_match_style (buffer);
+
+		if (buffer->priv->highlight_engine != NULL)
+		{
+			_gtk_source_engine_set_style_scheme (buffer->priv->highlight_engine, scheme);
+		}
+
+		g_object_notify_by_pspec (G_OBJECT (buffer), buffer_properties[PROP_STYLE_SCHEME]);
 	}
-
-	if (buffer->priv->style_scheme != NULL)
-	{
-		g_object_unref (buffer->priv->style_scheme);
-	}
-
-	buffer->priv->style_scheme = scheme != NULL ? g_object_ref (scheme) : NULL;
-	update_bracket_match_style (buffer);
-
-	if (buffer->priv->highlight_engine != NULL)
-	{
-		_gtk_source_engine_set_style_scheme (buffer->priv->highlight_engine, scheme);
-	}
-
-	g_object_notify (G_OBJECT (buffer), "style-scheme");
 }
 
 /**
@@ -2010,7 +2007,7 @@ gtk_source_buffer_real_redo (GtkSourceBuffer *buffer)
 /**
  * gtk_source_buffer_create_source_mark:
  * @buffer: a #GtkSourceBuffer.
- * @name: (allow-none): the name of the mark, or %NULL.
+ * @name: (nullable): the name of the mark, or %NULL.
  * @category: a string defining the mark category.
  * @where: location to place the mark.
  *
@@ -2109,7 +2106,7 @@ _gtk_source_buffer_source_mark_prev (GtkSourceBuffer *buffer,
  * gtk_source_buffer_forward_iter_to_source_mark:
  * @buffer: a #GtkSourceBuffer.
  * @iter: an iterator.
- * @category: (allow-none): category to search for, or %NULL
+ * @category: (nullable): category to search for, or %NULL
  *
  * Moves @iter to the position of the next #GtkSourceMark of the given
  * @category. Returns %TRUE if @iter was moved. If @category is NULL, the
@@ -2143,7 +2140,7 @@ gtk_source_buffer_forward_iter_to_source_mark (GtkSourceBuffer *buffer,
  * gtk_source_buffer_backward_iter_to_source_mark:
  * @buffer: a #GtkSourceBuffer.
  * @iter: an iterator.
- * @category: (allow-none): category to search for, or %NULL
+ * @category: (nullable): category to search for, or %NULL
  *
  * Moves @iter to the position of the previous #GtkSourceMark of the given
  * category. Returns %TRUE if @iter was moved. If @category is NULL, the
@@ -2177,7 +2174,7 @@ gtk_source_buffer_backward_iter_to_source_mark (GtkSourceBuffer *buffer,
  * gtk_source_buffer_get_source_marks_at_iter:
  * @buffer: a #GtkSourceBuffer.
  * @iter: an iterator.
- * @category: (allow-none): category to search for, or %NULL
+ * @category: (nullable): category to search for, or %NULL
  *
  * Returns the list of marks of the given category at @iter. If @category
  * is %NULL it returns all marks at @iter.
@@ -2211,7 +2208,7 @@ gtk_source_buffer_get_source_marks_at_iter (GtkSourceBuffer *buffer,
  * gtk_source_buffer_get_source_marks_at_line:
  * @buffer: a #GtkSourceBuffer.
  * @line: a line number.
- * @category: (allow-none): category to search for, or %NULL
+ * @category: (nullable): category to search for, or %NULL
  *
  * Returns the list of marks of the given category at @line.
  * If @category is %NULL, all marks at @line are returned.
@@ -2258,7 +2255,7 @@ gtk_source_buffer_get_source_marks_at_line (GtkSourceBuffer *buffer,
  * @buffer: a #GtkSourceBuffer.
  * @start: a #GtkTextIter.
  * @end: a #GtkTextIter.
- * @category: (allow-none): category to search for, or %NULL.
+ * @category: (nullable): category to search for, or %NULL.
  *
  * Remove all marks of @category between @start and @end from the buffer.
  * If @category is NULL, all marks in the range will be removed.
@@ -3034,7 +3031,7 @@ gtk_source_buffer_sort_lines (GtkSourceBuffer    *buffer,
 /**
  * gtk_source_buffer_set_undo_manager:
  * @buffer: a #GtkSourceBuffer.
- * @manager: (allow-none): A #GtkSourceUndoManager or %NULL.
+ * @manager: (nullable): A #GtkSourceUndoManager or %NULL.
  *
  * Set the buffer undo manager. If @manager is %NULL the default undo manager
  * will be set.
@@ -3061,7 +3058,7 @@ gtk_source_buffer_set_undo_manager (GtkSourceBuffer      *buffer,
 	set_undo_manager (buffer, manager);
 	g_object_unref (manager);
 
-	g_object_notify (G_OBJECT (buffer), "undo-manager");
+	g_object_notify_by_pspec (G_OBJECT (buffer), buffer_properties[PROP_UNDO_MANAGER]);
 }
 
 /**
@@ -3116,7 +3113,7 @@ sync_invalid_char_tag (GtkSourceBuffer *buffer,
 		style = gtk_source_style_scheme_get_style (buffer->priv->style_scheme, "def:error");
 	}
 
-	_gtk_source_style_apply (style, buffer->priv->invalid_char_tag);
+	gtk_source_style_apply (style, buffer->priv->invalid_char_tag);
 }
 
 static void
@@ -3219,7 +3216,7 @@ gtk_source_buffer_set_implicit_trailing_newline (GtkSourceBuffer *buffer,
 	if (buffer->priv->implicit_trailing_newline != implicit_trailing_newline)
 	{
 		buffer->priv->implicit_trailing_newline = implicit_trailing_newline;
-		g_object_notify (G_OBJECT (buffer), "implicit-trailing-newline");
+		g_object_notify_by_pspec (G_OBJECT (buffer), buffer_properties[PROP_IMPLICIT_TRAILING_NEWLINE]);
 	}
 }
 
