@@ -23,8 +23,8 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef __GTK_SOURCE_BUFFER_H__
-#define __GTK_SOURCE_BUFFER_H__
+#ifndef GTK_SOURCE_BUFFER_H
+#define GTK_SOURCE_BUFFER_H
 
 #include <gtk/gtk.h>
 #include <gtksourceview/gtksourcetypes.h>
@@ -117,120 +117,158 @@ struct _GtkSourceBufferClass
 	void (*_gtk_source_reserved3) (void);
 };
 
-GType           	 gtk_source_buffer_get_type				(void) G_GNUC_CONST;
+GTK_SOURCE_AVAILABLE_IN_ALL
+GType			 gtk_source_buffer_get_type				(void) G_GNUC_CONST;
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 GtkSourceBuffer	 	*gtk_source_buffer_new					(GtkTextTagTable        *table);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 GtkSourceBuffer 	*gtk_source_buffer_new_with_language			(GtkSourceLanguage      *language);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 gboolean		 gtk_source_buffer_get_highlight_syntax			(GtkSourceBuffer        *buffer);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 void			 gtk_source_buffer_set_highlight_syntax			(GtkSourceBuffer        *buffer,
 										 gboolean                highlight);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 gboolean		 gtk_source_buffer_get_highlight_matching_brackets	(GtkSourceBuffer        *buffer);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 void			 gtk_source_buffer_set_highlight_matching_brackets	(GtkSourceBuffer        *buffer,
 										 gboolean                highlight);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 gint			 gtk_source_buffer_get_max_undo_levels			(GtkSourceBuffer        *buffer);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 void			 gtk_source_buffer_set_max_undo_levels			(GtkSourceBuffer        *buffer,
 										 gint                    max_undo_levels);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 GtkSourceLanguage 	*gtk_source_buffer_get_language				(GtkSourceBuffer        *buffer);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 void			 gtk_source_buffer_set_language				(GtkSourceBuffer        *buffer,
 										 GtkSourceLanguage      *language);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 gboolean		 gtk_source_buffer_can_undo				(GtkSourceBuffer        *buffer);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 gboolean		 gtk_source_buffer_can_redo				(GtkSourceBuffer        *buffer);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 GtkSourceStyleScheme    *gtk_source_buffer_get_style_scheme			(GtkSourceBuffer        *buffer);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 void			 gtk_source_buffer_set_style_scheme			(GtkSourceBuffer        *buffer,
 										 GtkSourceStyleScheme   *scheme);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 void			 gtk_source_buffer_ensure_highlight			(GtkSourceBuffer        *buffer,
 										 const GtkTextIter      *start,
 										 const GtkTextIter      *end);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 void			 gtk_source_buffer_undo					(GtkSourceBuffer        *buffer);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 void			 gtk_source_buffer_redo					(GtkSourceBuffer        *buffer);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 void			 gtk_source_buffer_begin_not_undoable_action		(GtkSourceBuffer	*buffer);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 void			 gtk_source_buffer_end_not_undoable_action		(GtkSourceBuffer	*buffer);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 GtkSourceMark		*gtk_source_buffer_create_source_mark			(GtkSourceBuffer        *buffer,
 										 const gchar            *name,
 										 const gchar            *category,
 										 const GtkTextIter      *where);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 gboolean		 gtk_source_buffer_forward_iter_to_source_mark		(GtkSourceBuffer        *buffer,
 										 GtkTextIter            *iter,
 										 const gchar            *category);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 gboolean		 gtk_source_buffer_backward_iter_to_source_mark		(GtkSourceBuffer        *buffer,
 										 GtkTextIter            *iter,
 										 const gchar            *category);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 GSList			*gtk_source_buffer_get_source_marks_at_iter		(GtkSourceBuffer        *buffer,
 										 GtkTextIter            *iter,
 										 const gchar            *category);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 GSList			*gtk_source_buffer_get_source_marks_at_line		(GtkSourceBuffer        *buffer,
 										 gint 			 line,
 										 const gchar		*category);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 void			 gtk_source_buffer_remove_source_marks			(GtkSourceBuffer        *buffer,
 										 const GtkTextIter      *start,
 										 const GtkTextIter      *end,
 										 const gchar            *category);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 gboolean		 gtk_source_buffer_iter_has_context_class		(GtkSourceBuffer	*buffer,
 										 const GtkTextIter	*iter,
 										 const gchar            *context_class);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 gchar		       **gtk_source_buffer_get_context_classes_at_iter		(GtkSourceBuffer	*buffer,
 										 const GtkTextIter	*iter);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 gboolean		 gtk_source_buffer_iter_forward_to_context_class_toggle	(GtkSourceBuffer	*buffer,
 										 GtkTextIter		*iter,
 										 const gchar		*context_class);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 gboolean		 gtk_source_buffer_iter_backward_to_context_class_toggle
 										(GtkSourceBuffer	*buffer,
 										 GtkTextIter		*iter,
 										 const gchar		*context_class);
 
+GTK_SOURCE_AVAILABLE_IN_3_12
 void			 gtk_source_buffer_change_case				(GtkSourceBuffer        *buffer,
 										 GtkSourceChangeCaseType case_type,
 										 GtkTextIter            *start,
 										 GtkTextIter            *end);
 
+GTK_SOURCE_AVAILABLE_IN_3_16
 void			 gtk_source_buffer_join_lines				(GtkSourceBuffer        *buffer,
 										 GtkTextIter            *start,
 										 GtkTextIter            *end);
 
+GTK_SOURCE_AVAILABLE_IN_3_18
 void			 gtk_source_buffer_sort_lines				(GtkSourceBuffer        *buffer,
 										 GtkTextIter            *start,
 										 GtkTextIter            *end,
 										 GtkSourceSortFlags     flags,
 										 gint                   column);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 GtkSourceUndoManager	*gtk_source_buffer_get_undo_manager			(GtkSourceBuffer	*buffer);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 void			 gtk_source_buffer_set_undo_manager			(GtkSourceBuffer	*buffer,
 										 GtkSourceUndoManager	*manager);
 
+GTK_SOURCE_AVAILABLE_IN_3_14
 void			 gtk_source_buffer_set_implicit_trailing_newline	(GtkSourceBuffer        *buffer,
 										 gboolean                implicit_trailing_newline);
 
+GTK_SOURCE_AVAILABLE_IN_3_14
 gboolean		 gtk_source_buffer_get_implicit_trailing_newline	(GtkSourceBuffer        *buffer);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 GtkTextTag		*gtk_source_buffer_create_source_tag			(GtkSourceBuffer        *buffer,
 										 const gchar            *tag_name,
 										 const gchar            *first_property_name,
@@ -238,4 +276,4 @@ GtkTextTag		*gtk_source_buffer_create_source_tag			(GtkSourceBuffer        *buff
 
 G_END_DECLS
 
-#endif /* __GTK_SOURCE_BUFFER_H__ */
+#endif /* GTK_SOURCE_BUFFER_H */
