@@ -113,7 +113,6 @@
 #include "gtksourceview.h"
 #include "gtksourceview-i18n.h"
 
-/* Signals */
 enum
 {
 	SHOW,
@@ -125,7 +124,7 @@ enum
 	MOVE_CURSOR,
 	MOVE_PAGE,
 
-	LAST_SIGNAL
+	N_SIGNALS
 };
 
 enum
@@ -204,7 +203,7 @@ struct _GtkSourceCompletionPrivate
 	guint show_icons : 1;
 };
 
-static guint signals[LAST_SIGNAL] = { 0 };
+static guint signals[N_SIGNALS];
 
 static void	gtk_source_completion_buildable_interface_init (GtkBuildableIface *iface);
 
@@ -2739,7 +2738,7 @@ _gtk_source_completion_add_proposals (GtkSourceCompletion         *completion,
 /**
  * gtk_source_completion_show:
  * @completion: a #GtkSourceCompletion.
- * @providers: (element-type GtkSource.CompletionProvider) (allow-none):
+ * @providers: (element-type GtkSource.CompletionProvider) (nullable):
  * a list of #GtkSourceCompletionProvider, or %NULL.
  * @context: (transfer floating): The #GtkSourceCompletionContext
  * with which to start the completion.
@@ -2857,7 +2856,7 @@ gtk_source_completion_new (GtkSourceView *view)
  * gtk_source_completion_add_provider:
  * @completion: a #GtkSourceCompletion.
  * @provider: a #GtkSourceCompletionProvider.
- * @error: (allow-none): a #GError.
+ * @error: a #GError.
  *
  * Add a new #GtkSourceCompletionProvider to the completion object. This will
  * add a reference @provider, so make sure to unref your own copy when you
@@ -2902,7 +2901,7 @@ gtk_source_completion_add_provider (GtkSourceCompletion          *completion,
  * gtk_source_completion_remove_provider:
  * @completion: a #GtkSourceCompletion.
  * @provider: a #GtkSourceCompletionProvider.
- * @error: (allow-none): a #GError.
+ * @error: a #GError.
  *
  * Remove @provider from the completion.
  *
@@ -3004,7 +3003,7 @@ gtk_source_completion_get_view (GtkSourceCompletion *completion)
 /**
  * gtk_source_completion_create_context:
  * @completion: a #GtkSourceCompletion.
- * @position: (allow-none): a #GtkTextIter, or %NULL.
+ * @position: (nullable): a #GtkTextIter, or %NULL.
  *
  * Create a new #GtkSourceCompletionContext for @completion. The position where
  * the completion occurs can be specified by @position. If @position is %NULL,
