@@ -19,8 +19,8 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef __GTK_SOURCE_FILE_H__
-#define __GTK_SOURCE_FILE_H__
+#ifndef GTK_SOURCE_FILE_H
+#define GTK_SOURCE_FILE_H
 
 #include <gtk/gtk.h>
 #include <gtksourceview/gtksourcetypes.h>
@@ -147,4 +147,4 @@ void		 _gtk_source_file_set_readonly			(GtkSourceFile *file,
 
 G_END_DECLS
 
-#endif /* __GTK_SOURCE_FILE_H__ */
+#endif /* GTK_SOURCE_FILE_H */
