@@ -19,8 +19,8 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef __GTKSOURCEMARK_H__
-#define __GTKSOURCEMARK_H__
+#ifndef GTKSOURCEMARK_H
+#define GTKSOURCEMARK_H
 
 #include <gtk/gtk.h>
 #include <gtksourceview/gtksourcetypes.h>
@@ -54,18 +54,24 @@ struct _GtkSourceMarkClass
 	void (*_gtk_source_reserved2) (void);
 };
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 GType		 gtk_source_mark_get_type (void) G_GNUC_CONST;
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 GtkSourceMark   *gtk_source_mark_new		(const gchar	*name,
 						 const gchar	*category);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 const gchar	*gtk_source_mark_get_category	(GtkSourceMark	*mark);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 GtkSourceMark	*gtk_source_mark_next		(GtkSourceMark	*mark,
 						 const gchar	*category);
+
+GTK_SOURCE_AVAILABLE_IN_ALL
 GtkSourceMark	*gtk_source_mark_prev		(GtkSourceMark	*mark,
 						 const gchar	*category);
 
 G_END_DECLS
 
-#endif /* __GTKSOURCEMARK_H__ */
+#endif /* GTKSOURCEMARK_H */
