@@ -2,7 +2,7 @@
  * gtksourcesearchcontext.h
  * This file is part of GtkSourceView
  *
- * Copyright (C) 2013 - Sébastien Wilmet <swilmet@gnome.org>
+ * Copyright (C) 2013, 2016 - Sébastien Wilmet <swilmet@gnome.org>
  *
  * GtkSourceView is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -19,8 +19,8 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef __GTK_SOURCE_SEARCH_CONTEXT_H__
-#define __GTK_SOURCE_SEARCH_CONTEXT_H__
+#ifndef GTK_SOURCE_SEARCH_CONTEXT_H
+#define GTK_SOURCE_SEARCH_CONTEXT_H
 
 #include <gtk/gtk.h>
 #include <gtksourceview/gtksourcetypes.h>
@@ -93,12 +93,19 @@ gint			 gtk_source_search_context_get_occurrence_position	(GtkSourceSearchContex
 										 const GtkTextIter	 *match_start,
 										 const GtkTextIter	 *match_end);
 
-GTK_SOURCE_AVAILABLE_IN_3_10
+GTK_SOURCE_DEPRECATED_IN_3_22_FOR (gtk_source_search_context_forward2)
 gboolean		 gtk_source_search_context_forward			(GtkSourceSearchContext	 *search,
 										 const GtkTextIter	 *iter,
 										 GtkTextIter		 *match_start,
 										 GtkTextIter		 *match_end);
 
+GTK_SOURCE_AVAILABLE_IN_3_22
+gboolean		 gtk_source_search_context_forward2			(GtkSourceSearchContext *search,
+										 const GtkTextIter      *iter,
+										 GtkTextIter            *match_start,
+										 GtkTextIter            *match_end,
+										 gboolean               *has_wrapped_around);
+
 GTK_SOURCE_AVAILABLE_IN_3_10
 void			 gtk_source_search_context_forward_async		(GtkSourceSearchContext	 *search,
 										 const GtkTextIter	 *iter,
@@ -106,19 +113,34 @@ void			 gtk_source_search_context_forward_async		(GtkSourceSearchContext	 *searc
 										 GAsyncReadyCallback	  callback,
 										 gpointer		  user_data);
 
-GTK_SOURCE_AVAILABLE_IN_3_10
+GTK_SOURCE_DEPRECATED_IN_3_22_FOR (gtk_source_search_context_forward_finish2)
 gboolean		 gtk_source_search_context_forward_finish		(GtkSourceSearchContext	 *search,
 										 GAsyncResult		 *result,
 										 GtkTextIter		 *match_start,
 										 GtkTextIter		 *match_end,
 										 GError		        **error);
 
-GTK_SOURCE_AVAILABLE_IN_3_10
+GTK_SOURCE_AVAILABLE_IN_3_22
+gboolean		 gtk_source_search_context_forward_finish2		(GtkSourceSearchContext  *search,
+										 GAsyncResult            *result,
+										 GtkTextIter             *match_start,
+										 GtkTextIter             *match_end,
+										 gboolean                *has_wrapped_around,
+										 GError                 **error);
+
+GTK_SOURCE_DEPRECATED_IN_3_22_FOR (gtk_source_search_context_backward2)
 gboolean		 gtk_source_search_context_backward			(GtkSourceSearchContext	 *search,
 										 const GtkTextIter	 *iter,
 										 GtkTextIter		 *match_start,
 										 GtkTextIter		 *match_end);
 
+GTK_SOURCE_AVAILABLE_IN_3_22
+gboolean		 gtk_source_search_context_backward2			(GtkSourceSearchContext *search,
+										 const GtkTextIter      *iter,
+										 GtkTextIter            *match_start,
+										 GtkTextIter            *match_end,
+										 gboolean               *has_wrapped_around);
+
 GTK_SOURCE_AVAILABLE_IN_3_10
 void			 gtk_source_search_context_backward_async		(GtkSourceSearchContext	 *search,
 										 const GtkTextIter	 *iter,
@@ -126,14 +148,22 @@ void			 gtk_source_search_context_backward_async		(GtkSourceSearchContext	 *sear
 										 GAsyncReadyCallback	  callback,
 										 gpointer		  user_data);
 
-GTK_SOURCE_AVAILABLE_IN_3_10
+GTK_SOURCE_DEPRECATED_IN_3_22_FOR (gtk_source_search_context_backward_finish2)
 gboolean		 gtk_source_search_context_backward_finish		(GtkSourceSearchContext	 *search,
 										 GAsyncResult		 *result,
 										 GtkTextIter		 *match_start,
 										 GtkTextIter		 *match_end,
 										 GError		        **error);
 
-GTK_SOURCE_AVAILABLE_IN_3_10
+GTK_SOURCE_AVAILABLE_IN_3_22
+gboolean		 gtk_source_search_context_backward_finish2		(GtkSourceSearchContext  *search,
+										 GAsyncResult            *result,
+										 GtkTextIter             *match_start,
+										 GtkTextIter             *match_end,
+										 gboolean                *has_wrapped_around,
+										 GError                 **error);
+
+GTK_SOURCE_DEPRECATED_IN_3_22_FOR (gtk_source_search_context_replace2)
 gboolean		 gtk_source_search_context_replace			(GtkSourceSearchContext	 *search,
 										 const GtkTextIter	 *match_start,
 										 const GtkTextIter	 *match_end,
@@ -141,6 +171,14 @@ gboolean		 gtk_source_search_context_replace			(GtkSourceSearchContext	 *search,
 										 gint			  replace_length,
 										 GError			**error);
 
+GTK_SOURCE_AVAILABLE_IN_3_22
+gboolean		 gtk_source_search_context_replace2			(GtkSourceSearchContext  *search,
+										 GtkTextIter             *match_start,
+										 GtkTextIter             *match_end,
+										 const gchar             *replace,
+										 gint                     replace_length,
+										 GError                 **error);
+
 GTK_SOURCE_AVAILABLE_IN_3_10
 guint			 gtk_source_search_context_replace_all			(GtkSourceSearchContext	 *search,
 										 const gchar		 *replace,
@@ -155,4 +193,4 @@ void			 _gtk_source_search_context_update_highlight		(GtkSourceSearchContext	 *s
 
 G_END_DECLS
 
-#endif /* __GTK_SOURCE_SEARCH_CONTEXT_H__ */
+#endif /* GTK_SOURCE_SEARCH_CONTEXT_H */
