@@ -19,6 +19,10 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "gtksourcesearchsettings.h"
 #include "gtksourceview-i18n.h"
 
@@ -258,7 +262,7 @@ gtk_source_search_settings_new (void)
 /**
  * gtk_source_search_settings_set_search_text:
  * @settings: a #GtkSourceSearchSettings.
- * @search_text: (allow-none): the nul-terminated text to search, or %NULL to disable the search.
+ * @search_text: (nullable): the nul-terminated text to search, or %NULL to disable the search.
  *
  * Sets the text to search. If @text is %NULL or is empty, the search will be
  * disabled. A copy of @text will be made, so you can safely free @text after
@@ -449,6 +453,10 @@ gtk_source_search_settings_get_wrap_around (GtkSourceSearchSettings *settings)
  * If enabled, the #GtkSourceSearchSettings:search-text property contains the
  * pattern of the regular expression.
  *
+ * #GtkSourceSearchContext uses #GRegex when regex search is enabled. See the
+ * [Regular expression syntax](https://developer.gnome.org/glib/stable/glib-regex-syntax.html)
+ * page in the GLib reference manual.
+ *
  * Since: 3.10
  */
 void
