@@ -19,10 +19,10 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef __GTK_SOURCE_STYLE_H__
-#define __GTK_SOURCE_STYLE_H__
+#ifndef GTK_SOURCE_STYLE_H
+#define GTK_SOURCE_STYLE_H
 
-#include <glib-object.h>
+#include <gtk/gtk.h>
 #include <gtksourceview/gtksourcetypes.h>
 
 G_BEGIN_DECLS
@@ -42,6 +42,10 @@ GType		 gtk_source_style_get_type	(void) G_GNUC_CONST;
 GTK_SOURCE_AVAILABLE_IN_ALL
 GtkSourceStyle	*gtk_source_style_copy		(const GtkSourceStyle *style);
 
+GTK_SOURCE_AVAILABLE_IN_3_22
+void		 gtk_source_style_apply		(const GtkSourceStyle *style,
+						 GtkTextTag           *tag);
+
 G_END_DECLS
 
-#endif  /* __GTK_SOURCE_STYLE_H__ */
+#endif  /* GTK_SOURCE_STYLE_H */
