@@ -1,26 +1,25 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; coding: utf-8 -*-
- * gtk_sourcesourcestyleschemechooser.h
- * This file is part of gtk_sourcesourceview
+ *
+ * This file is part of GtkSourceView
  *
  * Copyright (C) 2014 - Ignacio Casal Quinteiro
  *
- * gtk_sourcesourceview is free software; you can redistribute it and/or
+ * GtkSourceView is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
  *
- * gtk_sourcesourceview is distributed in the hope that it will be useful,
+ * GtkSourceView is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with gtk_sourcesourceview. If not, see <http://www.gnu.org/licenses/>.
+ * along with GtkSourceView. If not, see <http://www.gnu.org/licenses/>.
  */
 
-
-#ifndef __GTK_SOURCE_STYLE_SCHEME_CHOOSER_H__
-#define __GTK_SOURCE_STYLE_SCHEME_CHOOSER_H__
+#ifndef GTK_SOURCE_STYLE_SCHEME_CHOOSER_H
+#define GTK_SOURCE_STYLE_SCHEME_CHOOSER_H
 
 #include <gtksourceview/gtksourcetypes.h>
 
@@ -48,13 +47,16 @@ struct _GtkSourceStyleSchemeChooserInterface
 	gpointer padding[12];
 };
 
+GTK_SOURCE_AVAILABLE_IN_3_16
 GType                     gtk_source_style_scheme_chooser_get_type               (void) G_GNUC_CONST;
 
+GTK_SOURCE_AVAILABLE_IN_3_16
 GtkSourceStyleScheme     *gtk_source_style_scheme_chooser_get_style_scheme       (GtkSourceStyleSchemeChooser *chooser);
 
+GTK_SOURCE_AVAILABLE_IN_3_16
 void                      gtk_source_style_scheme_chooser_set_style_scheme       (GtkSourceStyleSchemeChooser *chooser,
                                                                                   GtkSourceStyleScheme        *scheme);
 
 G_END_DECLS
 
-#endif /* __GTK_SOURCE_STYLE_SCHEME_CHOOSER_H__ */
+#endif /* GTK_SOURCE_STYLE_SCHEME_CHOOSER_H */
