@@ -19,12 +19,11 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef __GTK_SOURCE_STYLE_SCHEME_MANAGER_H__
-#define __GTK_SOURCE_STYLE_SCHEME_MANAGER_H__
+#ifndef GTK_SOURCE_STYLE_SCHEME_MANAGER_H
+#define GTK_SOURCE_STYLE_SCHEME_MANAGER_H
 
 #include <glib-object.h>
 #include <gtksourceview/gtksourcetypes.h>
-#include <gtksourceview/gtksourcestylescheme.h>
 
 G_BEGIN_DECLS
 
@@ -35,7 +34,6 @@ G_BEGIN_DECLS
 #define GTK_SOURCE_IS_STYLE_SCHEME_MANAGER_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE ((klass), GTK_SOURCE_TYPE_STYLE_SCHEME_MANAGER))
 #define GTK_SOURCE_STYLE_SCHEME_MANAGER_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS((obj), GTK_SOURCE_TYPE_STYLE_SCHEME_MANAGER, GtkSourceStyleSchemeManagerClass))
 
-
 typedef struct _GtkSourceStyleSchemeManagerClass	GtkSourceStyleSchemeManagerClass;
 typedef struct _GtkSourceStyleSchemeManagerPrivate	GtkSourceStyleSchemeManagerPrivate;
 
@@ -57,34 +55,42 @@ struct _GtkSourceStyleSchemeManagerClass
 	void (*_gtk_source_reserved4) (void);
 };
 
-
+GTK_SOURCE_AVAILABLE_IN_ALL
 GType			 gtk_source_style_scheme_manager_get_type		(void) G_GNUC_CONST;
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 GtkSourceStyleSchemeManager *
 			 gtk_source_style_scheme_manager_new			(void);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 GtkSourceStyleSchemeManager *
 			 gtk_source_style_scheme_manager_get_default		(void);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 void			 gtk_source_style_scheme_manager_set_search_path	(GtkSourceStyleSchemeManager	*manager,
 						    				 gchar			       **path);
 
-void 			 gtk_source_style_scheme_manager_append_search_path    (GtkSourceStyleSchemeManager	*manager,
+GTK_SOURCE_AVAILABLE_IN_ALL
+void 			 gtk_source_style_scheme_manager_append_search_path	(GtkSourceStyleSchemeManager	*manager,
 						    				 const gchar			*path);
 
-void 			 gtk_source_style_scheme_manager_prepend_search_path   (GtkSourceStyleSchemeManager	*manager,
+GTK_SOURCE_AVAILABLE_IN_ALL
+void 			 gtk_source_style_scheme_manager_prepend_search_path	(GtkSourceStyleSchemeManager	*manager,
 						    				 const gchar			*path);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 const gchar * const *	 gtk_source_style_scheme_manager_get_search_path	(GtkSourceStyleSchemeManager	*manager);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 void			 gtk_source_style_scheme_manager_force_rescan		(GtkSourceStyleSchemeManager	*manager);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 const gchar * const *	 gtk_source_style_scheme_manager_get_scheme_ids		(GtkSourceStyleSchemeManager	*manager);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 GtkSourceStyleScheme	*gtk_source_style_scheme_manager_get_scheme		(GtkSourceStyleSchemeManager	*manager,
 										 const gchar			*scheme_id);
 
 G_END_DECLS
 
-#endif /* __GTK_SOURCE_STYLE_SCHEME_MANAGER_H__ */
-
+#endif /* GTK_SOURCE_STYLE_SCHEME_MANAGER_H */
