@@ -19,10 +19,11 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef __GTK_SOURCE_TYPES_H__
-#define __GTK_SOURCE_TYPES_H__
+#ifndef GTK_SOURCE_TYPES_H
+#define GTK_SOURCE_TYPES_H
 
 #include <gio/gio.h>
+#include <gtksourceview/gtksourceversion.h>
 
 G_BEGIN_DECLS
 
@@ -112,4 +113,4 @@ typedef enum
 
 G_END_DECLS
 
-#endif /* __GTK_SOURCE_TYPES_H__ */
+#endif /* GTK_SOURCE_TYPES_H */
